import request from '@/utils/request'

// 查询疫情地理地址列表
export function listAddr(query) {
  return request({
    url: '/yiqing/addr/list',
    method: 'get',
    params: query
  })
}

// 查询疫情地理地址详细
export function getAddr(addrId) {
  return request({
    url: '/yiqing/addr/' + addrId,
    method: 'get'
  })
}

// 新增疫情地理地址
export function addAddr(data) {
  return request({
    url: '/yiqing/addr',
    method: 'post',
    data: data
  })
}

// 修改疫情地理地址
export function updateAddr(data) {
  return request({
    url: '/yiqing/addr',
    method: 'put',
    data: data
  })
}

// 删除疫情地理地址
export function delAddr(addrId) {
  return request({
    url: '/yiqing/addr/' + addrId,
    method: 'delete'
  })
}

// 导出疫情地理地址
export function exportAddr(query) {
  return request({
    url: '/yiqing/addr/export',
    method: 'get',
    params: query
  })
}

// 模板下载
export function importTemplate() {
  return request({
    url: '/yiqing/addr/importTemplate',
    method: 'get',
  })
}
